%bcond_with tests

Summary:        Federated Messaging with ZeroMQ
Name:           fedmsg
Version:        1.1.7
Release:        5%{?dist}
License:        LGPL-2.1-or-later
URL:            https://github.com/fedora-infra/fedmsg
Source0:        %{url}/archive/%{version}/%{name}-%{version}.tar.gz
Source1:        %{name}-tmpfiles.conf
Source2:        fedmsg-gateway-3.service
Source3:        fedmsg-hub-3.service
Source4:        fedmsg-irc-3.service
Source5:        fedmsg-relay-3.service

BuildRequires:  make
BuildRequires:  gnupg systemd
BuildRequires:  python3-sphinx python3-arrow python3-click python3-cryptography python3-devel
BuildRequires:  python3-kitchen python3-mock python3-setuptools python3-six python3-sqlalchemy
BuildRequires:  python3-pytest python3-requests python3-rpm-macros python3-pyOpenSSL
BuildRequires:  python3-pygments python3-psutil python3-moksha-hub python3-vcrpy
Requires:       python3-fedmsg = %{version}-%{release}
%{?systemd_requires}

BuildArch:      noarch

%description
fedmsg (Federated Message Bus) is a library built on ZeroMQ using the
PyZMQ Python bindings. fedmsg aims to make it easy to connect services
together using ZeroMQ publishers and subscribers.


%package base
Summary: Base file system layout for other fedmsg packages

%description base
This package contains some of the common filesystem layout shared by the
python2 and python3 versions of the fedmsg package.


%package doc
Summary: Documentation for the fedmsg library and CLI

%description doc
Documentation for the fedmsg library and CLI.


%package -n python3-fedmsg
Summary:        Python 3 API and CLI for fedmsg
Requires:       python3-arrow python3-click python3-cryptography python3-kitchen python3-moksha-hub
Requires:       python3-psutil python3-pygments python3-pyOpenSSL python3-requests python3-six python3-zmq
Requires:       fedmsg-base = %{version}-%{release}
Provides:       python3-fedmsg-core = %{version}-%{release}
Obsoletes:      python3-fedmsg-core < %{version}-%{release}

%description -n python3-fedmsg
Python 3 API used around Fedora Infrastructure to send and receive messages
with zeromq.


%prep
%autosetup -n %{name}-%{version}


%build
%py3_build
%make_build -C doc SPHINXBUILD=sphinx-build-3 html PYTHONPATH=$(pwd)
rm doc/_build/html/.buildinfo


%install
%py3_install

mv %{buildroot}%{_bindir}/fedmsg-config %{buildroot}%{_bindir}/fedmsg-config-%{python3_version}
ln -s %{_bindir}/fedmsg-config-%{python3_version} %{buildroot}%{_bindir}/fedmsg-config-3
ln -s %{_bindir}/fedmsg-config-3 %{buildroot}%{_bindir}/fedmsg-config

mv %{buildroot}%{_bindir}/fedmsg-logger %{buildroot}%{_bindir}/fedmsg-logger-%{python3_version}
ln -s %{_bindir}/fedmsg-logger-%{python3_version} %{buildroot}%{_bindir}/fedmsg-logger-3
ln -s %{_bindir}/fedmsg-logger-3 %{buildroot}%{_bindir}/fedmsg-logger

mv %{buildroot}%{_bindir}/fedmsg-tail %{buildroot}%{_bindir}/fedmsg-tail-%{python3_version}
ln -s %{_bindir}/fedmsg-tail-%{python3_version} %{buildroot}%{_bindir}/fedmsg-tail-3
ln -s %{_bindir}/fedmsg-tail-3 %{buildroot}%{_bindir}/fedmsg-tail

mv %{buildroot}%{_bindir}/fedmsg-collectd %{buildroot}%{_bindir}/fedmsg-collectd-%{python3_version}
ln -s %{_bindir}/fedmsg-collectd-%{python3_version} %{buildroot}%{_bindir}/fedmsg-collectd-3
ln -s %{_bindir}/fedmsg-collectd-3 %{buildroot}%{_bindir}/fedmsg-collectd

mv %{buildroot}%{_bindir}/fedmsg-announce %{buildroot}%{_bindir}/fedmsg-announce-%{python3_version}
ln -s %{_bindir}/fedmsg-announce-%{python3_version} %{buildroot}%{_bindir}/fedmsg-announce-3
ln -s %{_bindir}/fedmsg-announce-3 %{buildroot}%{_bindir}/fedmsg-announce

mv %{buildroot}%{_bindir}/fedmsg-trigger %{buildroot}%{_bindir}/fedmsg-trigger-%{python3_version}
ln -s %{_bindir}/fedmsg-trigger-%{python3_version} %{buildroot}%{_bindir}/fedmsg-trigger-3
ln -s %{_bindir}/fedmsg-trigger-3 %{buildroot}%{_bindir}/fedmsg-trigger

mv %{buildroot}%{_bindir}/fedmsg-dg-replay %{buildroot}%{_bindir}/fedmsg-dg-replay-%{python3_version}
ln -s %{_bindir}/fedmsg-dg-replay-%{python3_version} %{buildroot}%{_bindir}/fedmsg-dg-replay-3
ln -s %{_bindir}/fedmsg-dg-replay-3 %{buildroot}%{_bindir}/fedmsg-dg-replay

mv %{buildroot}%{_bindir}/fedmsg-check %{buildroot}%{_bindir}/fedmsg-check-%{python3_version}
ln -s %{_bindir}/fedmsg-check-%{python3_version} %{buildroot}%{_bindir}/fedmsg-check-3
ln -s %{_bindir}/fedmsg-check-3 %{buildroot}%{_bindir}/fedmsg-check

mv %{buildroot}%{_bindir}/fedmsg-hub %{buildroot}%{_bindir}/fedmsg-hub-%{python3_version}
ln -s %{_bindir}/fedmsg-hub-%{python3_version} %{buildroot}%{_bindir}/fedmsg-hub-3
ln -s %{_bindir}/fedmsg-hub-3 %{buildroot}%{_bindir}/fedmsg-hub

mv %{buildroot}%{_bindir}/fedmsg-relay %{buildroot}%{_bindir}/fedmsg-relay-%{python3_version}
ln -s %{_bindir}/fedmsg-relay-%{python3_version} %{buildroot}%{_bindir}/fedmsg-relay-3
ln -s %{_bindir}/fedmsg-relay-3 %{buildroot}%{_bindir}/fedmsg-relay

mv %{buildroot}%{_bindir}/fedmsg-signing-relay %{buildroot}%{_bindir}/fedmsg-signing-relay-%{python3_version}
ln -s %{_bindir}/fedmsg-signing-relay-%{python3_version} %{buildroot}%{_bindir}/fedmsg-signing-relay-3
ln -s %{_bindir}/fedmsg-signing-relay-3 %{buildroot}%{_bindir}/fedmsg-signing-relay

mv %{buildroot}%{_bindir}/fedmsg-gateway %{buildroot}%{_bindir}/fedmsg-gateway-%{python3_version}
ln -s %{_bindir}/fedmsg-gateway-%{python3_version} %{buildroot}%{_bindir}/fedmsg-gateway-3
ln -s %{_bindir}/fedmsg-gateway-3 %{buildroot}%{_bindir}/fedmsg-gateway

mv %{buildroot}%{_bindir}/fedmsg-irc %{buildroot}%{_bindir}/fedmsg-irc-%{python3_version}
ln -s %{_bindir}/fedmsg-irc-%{python3_version} %{buildroot}%{_bindir}/fedmsg-irc-3
ln -s %{_bindir}/fedmsg-irc-3 %{buildroot}%{_bindir}/fedmsg-irc


mkdir -p %{buildroot}%{_sysconfdir}/fedmsg.d/
cp fedmsg.d/*.py %{buildroot}%{_sysconfdir}/fedmsg.d/.

mkdir -p %{buildroot}/%{_var}/run/%{name}
mkdir -p %{buildroot}/%{_var}/log/%{name}

mkdir -p %{buildroot}%{_unitdir}
install -Dm0644 %{SOURCE2} %{buildroot}%{_unitdir}/
install -Dm0644 %{SOURCE3} %{buildroot}%{_unitdir}/
install -Dm0644 %{SOURCE4} %{buildroot}%{_unitdir}/
install -Dm0644 %{SOURCE5} %{buildroot}%{_unitdir}/

ln -s ./fedmsg-hub-3.service %{buildroot}%{_unitdir}/fedmsg-hub.service
ln -s ./fedmsg-relay-3.service %{buildroot}%{_unitdir}/fedmsg-relay.service
ln -s ./fedmsg-irc-3.service %{buildroot}%{_unitdir}/fedmsg-irc.service
ln -s ./fedmsg-gateway-3.service %{buildroot}%{_unitdir}/fedmsg-gateway.service

mkdir -p %{buildroot}/%{_sysconfdir}/logrotate.d
install logrotate %{buildroot}/%{_sysconfdir}/logrotate.d/%{name}
chmod 0644 %{buildroot}/%{_sysconfdir}/logrotate.d/%{name}

install -Dm0644 %{SOURCE1} %{buildroot}%{_tmpfilesdir}/%{name}.conf


%if %{with tests}
%check
PYTHONPATH=$(pwd) py.test-3 fedmsg
rm -f %{buildroot}%{_sysconfdir}/fedmsg.d/*.py{c,o}
%endif


%pre base
%{_sbindir}/groupadd -r %{name} &>/dev/null || :
%{_sbindir}/useradd  -r -s /sbin/nologin -d %{_datadir}/%{name} -M \
                     -c 'FedMsg' -g %{name} %{name} &>/dev/null || :
%post -n python3-fedmsg
%systemd_post fedmsg-hub-3.service fedmsg-relay-3.service fedmsg-irc-3.service fedmsg-gateway-3.service

%preun -n python3-fedmsg
%systemd_preun fedmsg-hub-3.service fedmsg-relay-3.service fedmsg-irc-3.service fedmsg-gateway-3.service

%postun -n python3-fedmsg
%systemd_postun_with_restart fedmsg-hub-3.service fedmsg-relay-3.service fedmsg-irc-3.service fedmsg-gateway-3.service


%files
%license LICENSE
%doc README.rst


%files doc
%license LICENSE
%doc README.rst doc/_build/html


%files -n python3-fedmsg
%license LICENSE
%doc README.rst
%{python3_sitelib}/%{name}/
%{python3_sitelib}/%{name}-%{version}-py%{python3_version}.egg-info/
%{_bindir}/fedmsg-announce
%{_bindir}/fedmsg-announce-3*
%{_bindir}/fedmsg-collectd
%{_bindir}/fedmsg-collectd-3*
%{_bindir}/fedmsg-config
%{_bindir}/fedmsg-config-3*
%{_bindir}/fedmsg-gateway
%{_bindir}/fedmsg-gateway-3*
%{_bindir}/fedmsg-hub
%{_bindir}/fedmsg-hub-3*
%{_bindir}/fedmsg-irc
%{_bindir}/fedmsg-irc-3*
%{_bindir}/fedmsg-relay
%{_bindir}/fedmsg-relay-3*
%{_bindir}/fedmsg-logger
%{_bindir}/fedmsg-logger-3*
%{_bindir}/fedmsg-tail
%{_bindir}/fedmsg-tail-3*
%{_bindir}/fedmsg-trigger
%{_bindir}/fedmsg-trigger-3*
%{_bindir}/fedmsg-dg-replay
%{_bindir}/fedmsg-dg-replay-3*
%{_bindir}/fedmsg-signing-relay
%{_bindir}/fedmsg-signing-relay-3*
%{_bindir}/fedmsg-check
%{_bindir}/fedmsg-check-3*
%{_unitdir}/fedmsg-hub.service
%{_unitdir}/fedmsg-hub-3.service
%{_unitdir}/fedmsg-relay.service
%{_unitdir}/fedmsg-relay-3.service
%{_unitdir}/fedmsg-irc.service
%{_unitdir}/fedmsg-irc-3.service
%{_unitdir}/fedmsg-gateway.service
%{_unitdir}/fedmsg-gateway-3.service


%files base
%license LICENSE
%doc README.rst
%attr(755, %{name}, %{name}) %dir %{_var}/log/%{name}
%attr(775, %{name}, %{name}) %dir %{_var}/run/%{name}
%dir %{_sysconfdir}/fedmsg.d/
%config(noreplace) %{_sysconfdir}/fedmsg.d/*
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%{_tmpfilesdir}/%{name}.conf


%changelog
* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.1.7-5
- Rebuilt for loongarch release

* Tue Sep 19 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.1.7-4
- Rebuilt for python 3.11

* Mon Sep 18 2023 Miaojun Dong <zoedong@tencent.com> - 1.1.7-3
- Rebuild for pyOpenSSL-23.2.0

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.1.7-2
- Rebuilt for OpenCloudOS Stream 23.09

* Sat May 06 2023 Miaojun Dong <zoedong@tencent.com> - 1.1.7-1
- initial build
